@@ -1,3 +1,4 @@
+"""Package for providing statistics and predictions for a given dataset."""
 from .base_column_profilers import BaseColumnProfiler
 from .categorical_column_profile import CategoricalColumn
 from .data_labeler_column_profile import DataLabelerColumn
@@ -9,8 +10,3 @@ from .order_column_profile import OrderColumn
 from .profile_builder import Profiler, StructuredProfiler, UnstructuredProfiler
 from .text_column_profile import TextColumn
 from .unstructured_labeler_profile import UnstructuredLabelerProfile
-
-"""
-The purpose of this package is to provide statistics and predictions for a 
-given dataset.
-"""
\ No newline at end of file
