@@ -1,5 +1,3 @@
-from __future__ import absolute_import, print_function
-
 import os
 import unittest
 from io import BytesIO, StringIO
@@ -68,7 +66,7 @@ class TestJSONDataClass(unittest.TestCase):
         for input_file in cls.input_file_names:
             # add StringIO
             buffer_info = input_file.copy()
-            with open(input_file["path"], "r", encoding=input_file["encoding"]) as fp:
+            with open(input_file["path"], encoding=input_file["encoding"]) as fp:
                 buffer_info["path"] = StringIO(fp.read())
             cls.buffer_list.append(buffer_info)
 
